@@ -1,8 +1,3 @@
-imports.gi.versions.Gio = '2.0';
-imports.gi.versions.GLib = '2.0';
-imports.gi.versions.Gtk = '3.0';
-imports.gi.versions.TelepathyGLib = '0.12';
-
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
@@ -12,10 +7,7 @@ const Tp = imports.gi.TelepathyGLib;
 const AccountsMonitor = imports.accountsMonitor;
 const AppNotifications = imports.appNotifications;
 const ChatroomManager = imports.chatroomManager;
-const Config = imports.config;
 const Connections = imports.connections;
-const Format = imports.format;
-const Gettext = imports.gettext;
 const Lang = imports.lang;
 const MainWindow = imports.mainWindow;
 const PasteManager = imports.pasteManager;
@@ -36,24 +28,13 @@ const Application = new Lang.Class({
     _init: function() {
         this.parent({ application_id: 'org.gnome.Polari' });
 
-        Gettext.bindtextdomain('polari', Config.LOCALE_DIR);
-        Gettext.textdomain('polari');
-        GLib.set_prgname('org.gnome.Polari');
         GLib.set_application_name('Polari');
         this._window = null;
         this._pendingRequests = {};
     },
 
     vfunc_startup: function() {
-        let resource = Gio.Resource.load(Config.RESOURCE_DIR + '/polari.gresource');
-        resource._register();
-
         this.parent();
-        String.prototype.format = Format.format;
-
-        window._ = Gettext.gettext;
-        window.C_ = Gettext.pgettext;
-        window.ngettext = Gettext.ngettext;
 
         let w = new Polari.FixedSizeFrame(); // register gtype
         w.destroy();
@@ -66,7 +47,7 @@ const Application = new Lang.Class({
                 this._removeSavedChannelsForAccount(account);
             }));
 
-        this._settings = new Gio.Settings({ schema_id: 'org.gnome.polari' });
+        this._settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
 
         this.pasteManager = new PasteManager.PasteManager();
         this.notificationQueue = new AppNotifications.NotificationQueue();
@@ -96,16 +77,11 @@ const Application = new Lang.Class({
             activate: Lang.bind(this, this._onLeaveCurrentRoom),
             create_hook: Lang.bind(this, this._leaveRoomCreateHook),
             accels: ['<Primary>w'] },
-          { name: 'leave-selected-rooms' },
           { name: 'user-list',
             activate: Lang.bind(this, this._onToggleAction),
             create_hook: Lang.bind(this, this._userListCreateHook),
             state: GLib.Variant.new('b', false),
             accels: ['F9', '<Primary>u'] },
-          { name: 'selection-mode',
-            activate: Lang.bind(this, this._onToggleAction),
-            create_hook: Lang.bind(this, this._selectionModeHook),
-            state: GLib.Variant.new('b', false) },
           { name: 'connections',
             activate: Lang.bind(this, this._onListConnections) },
           { name: 'preferences',
@@ -205,22 +181,6 @@ const Application = new Lang.Class({
         this._updateUserListAction(action);
     },
 
-    _updateSelectionModeAction: function(action) {
-        action.enabled = this._chatroomManager.getActiveRoom() != null;
-    },
-
-    _selectionModeHook: function(action) {
-        this._chatroomManager.connect('active-changed', Lang.bind(this,
-            function() {
-                this._updateSelectionModeAction(action);
-            }));
-        action.connect('notify::enabled', function() {
-            if (!action.enabled)
-                action.change_state(GLib.Variant.new('b', false));
-        });
-        this._updateSelectionModeAction(action);
-    },
-
     _onShowJoinDialog: function() {
         this._window.showJoinRoomDialog();
     },
@@ -437,11 +397,16 @@ const Application = new Lang.Class({
         }
         let aboutParams = {
             authors: [
-                'Florian M' + String.fromCharCode(0x00FC) // ü
-                            + 'llner <fmuellner@gnome.org>',
+                'Florian Müllner <fmuellner@gnome.org>',
+                'William Jon McCann <william.jon.mccann@gmail.com>',
+                'Carlos Soriano <carlos.soriano89@gmail.com>',
+                'Giovanni Campagna <gcampagna@src.gnome.org>',
+                'Carlos Garnacho <carlosg@gnome.org>',
+                'Jonas Danielsson <jonas.danielsson@threetimestwo.org>'
             ],
             artists: [
                 'Sam Hewitt',
+                'Jakub Steiner <jimmac@gmail.com>'
             ],
             translator_credits: _("translator-credits"),
             comments: _("An Internet Relay Chat Client for GNOME"),
@@ -450,7 +415,7 @@ const Application = new Lang.Class({
             license_type: Gtk.License.GPL_2_0,
             logo_icon_name: 'polari',
             wrap_license: true,
-            version: Config.PACKAGE_VERSION,
+            version: pkg.version,
 
             transient_for: this._window.window,
             modal: true
