@@ -21,7 +21,7 @@ const JoinDialog = new Lang.Class({
     _init: function() {
         this._createWidget();
 
-        this._settings = new Gio.Settings({ schema: 'org.gnome.polari' });
+        this._settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
 
         this._accountsMonitor = AccountsMonitor.getDefault();
 
@@ -45,6 +45,11 @@ const JoinDialog = new Lang.Class({
                     this._updateConnectionCombo();
                 }));
 
+        this.widget.connect('response', Lang.bind(this,
+            function(w, response) {
+                if (response == Gtk.ResponseType.OK)
+                    this._onConfirmClicked();
+            }));
         this.widget.connect('destroy', Lang.bind(this,
             function() {
                 this._accountsMonitor.disconnect(this._accountAddedId);
@@ -63,13 +68,11 @@ const JoinDialog = new Lang.Class({
 
         this.widget = builder.get_object('join_room_dialog');
 
-        this._titlebar = builder.get_object('titlebar');
-
         this._stack = builder.get_object('stack');
 
-        this._details = new Connections.ConnectionDetails(null);
-        this._stack.add_named(this._details.widget, 'connection');
-        this._details.connect('can-confirm-changed',
+        this._details = new Connections.ConnectionDetails();
+        this._stack.add_named(this._details, 'connection');
+        this._details.connect('notify::can-confirm',
                               Lang.bind(this, this._updateCanConfirm));
 
         this._connectionButton = builder.get_object('add_connection_button');
@@ -77,17 +80,14 @@ const JoinDialog = new Lang.Class({
             function() {
                 this._setPage(DialogPage.CONNECTION);
             }));
-        this._backButton = builder.get_object('back_button');
+
+        let icon = new Gtk.Image({ icon_name: 'go-previous-symbolic' });
+        this._backButton = new Gtk.Button({ image: icon });
         this._backButton.connect('clicked', Lang.bind(this,
             function() {
                 this._setPage(DialogPage.MAIN);
             }));
-
-        let backIcon = builder.get_object('back_icon');
-        if (backIcon.get_direction() == Gtk.TextDirection.RTL)
-            backIcon.icon_name = 'go-previous-rtl-symbolic';
-        else
-            backIcon.icon_name = 'go-previous-symbolic';
+        this.widget.get_header_bar().pack_start(this._backButton);
 
         this._connectionCombo = builder.get_object('connection_combo');
         this._connectionCombo.connect('changed',
@@ -95,9 +95,6 @@ const JoinDialog = new Lang.Class({
         this._connectionCombo.sensitive = false;
 
         this._confirmButton = builder.get_object('confirm_button');
-        this._confirmButton.connect('clicked',
-                                    Lang.bind(this, this._onConfirmClicked));
-
         this._cancelButton = builder.get_object('cancel_button');
 
         this._nameCompletion = builder.get_object('name_completion');
@@ -141,7 +138,6 @@ const JoinDialog = new Lang.Class({
     _onConfirmClicked: function() {
         if (this._page == DialogPage.MAIN) {
             this._joinRoom();
-            this.widget.response(Gtk.ResponseType.OK);
         } else {
             this._details.save();
             this._setPage(DialogPage.MAIN);
@@ -183,7 +179,9 @@ const JoinDialog = new Lang.Class({
 
         let factory = Tp.AccountManager.dup().get_factory();
         let lastUsed = factory.ensure_account(this._settings.get_string('last-used-account'), []);
-        let activeIndex = lastUsed ? names.indexOf(lastUsed.display_name) : 0;
+        let activeIndex = 0;
+        if (lastUsed)
+            activeIndex = Math.max(names.indexOf(lastUsed.display_name), 0);
         this._connectionCombo.set_active(activeIndex);
     },
 
@@ -217,8 +215,8 @@ const JoinDialog = new Lang.Class({
 
         this._backButton.visible = !isMain;
         this._cancelButton.visible = isMain;
-        this._titlebar.title = isMain ? _("Join Chat Room")
-                                      : _("Add Connection");
+        this.widget.title = isMain ? _("Join Chat Room")
+                                   : _("Add Connection");
         this._confirmButton.label = isMain ? _("_Join")
                                            : _("_Save");
         this._stack.visible_child_name = isMain ? 'main' : 'connection';
